from .models import *
import re
from django.db.models import Q

class TelefonosClientes(list):
    ''' diccionario de sms. '''
    
    def __init__(self, clientes=None, zona=None):
        self.clientes_con_telefono_invalido = []
        self.telefono_default = Registry.objects.get( nombre = 'SIC_SMS_TelDefault').get_value()
        self.telefonos=[]

        if clientes:
            self.clientes_sin_mensaje = clientes
        else:
            self.clientes_sin_mensaje = []    
        
        if clientes:
            self.get_telefonos_seleccion(clientes=clientes)
        elif zona:
            self.get_telefonos_zona(zona=zona)
        else:
            self.get_telefonos_todos()


    def validar_numeros(self,clientes):
        for cliente in clientes:
            cliente_nombre =  cliente[0].lstrip().rstrip()
            telefono =  cliente[1]
            if telefono:
                telefono = telefono.encode('utf-8')
                telefono = re.sub("[^0-9]", "", str(telefono))
                print(telefono)

                #validacion de telefonos invalidos  y creacion de mensajes
                if len(telefono) != 10 and cliente_nombre not in self.clientes_con_telefono_invalido:
                    # print("not")
                    # print(telefono)
                    self.clientes_con_telefono_invalido.append(cliente_nombre)
                elif not telefono in self.telefonos:
                    # print("yes")
                    # print(telefono)
                    self.telefonos.append(telefono)
            else:
                if not telefono in self.clientes_con_telefono_invalido:
                    self.clientes_con_telefono_invalido.append(cliente_nombre)
                    A = self.clientes_con_telefono_invalido
            
    def get_telefonos_todos(self):
        clientes = ClienteDireccion.objects.filter(es_ppal='S').filter(Q(cliente__no_enviar_sms=None) | Q(cliente__no_enviar_sms=0)).order_by('telefono1').values_list('cliente__nombre','telefono1',)
        self.validar_numeros(clientes)

    def get_telefonos_seleccion(self,clientes):
        clientes = ClienteDireccion.objects.filter(es_ppal='S', cliente__in=clientes).filter(Q(cliente__no_enviar_sms=None) | Q(cliente__no_enviar_sms=0)).order_by('telefono1').values_list('cliente__nombre','telefono1',)
        self.validar_numeros(clientes)

    def get_telefonos_zona(self,zona):
        clientes = ClienteDireccion.objects.filter(es_ppal='S', cliente__zona=zona).filter(Q(cliente__no_enviar_sms=None) | Q(cliente__no_enviar_sms=0)).order_by('telefono1').values_list('cliente__nombre','telefono1',)
        self.validar_numeros(clientes)

    def get_clientes_sin_mensajes(self):
        clientes = Cliente.objects.filter(id__in=self.clientes_sin_mensaje).values_list('nombre', flat=True)
        return clientes



#----encoding:utf-8------------
from django import forms
from .models import *
from django.core.validators import RegexValidator
from microsip_api.apps.sms.core import SMSMasivo


def UpdateRegistry(registry_name, value):
    registry = Registry.objects.get(nombre=registry_name)
    registry.valor = value
    registry.save()


class PreferenciasManageForm(forms.Form):
    enviar_remisiones = forms.BooleanField(label='Enviar remisiones Pendientes', required=False)
    resumir_mensajes = forms.BooleanField(label='Resumir mensajes', required=False)
    empresa_nombre = forms.CharField(widget=forms.TextInput(attrs={'autocomplete':"off",'class':'col-md-12', }))  
    informacion_extra = forms.CharField(widget=forms.TextInput(attrs={'autocomplete':"off",'class':'col-md-12', }), required=False)  
    telefono_default = forms.CharField(max_length=10, validators=[RegexValidator(regex='^\d{10}$', message='Longitud de 10', code='TGelefono invalido')], required=False)
    apikey = forms.CharField(max_length=41,widget=forms.PasswordInput ,required=False)
    monto_minimo = forms.DecimalField(max_digits=7, decimal_places=2)
    dias_atraso = forms.DecimalField(max_digits=10, decimal_places=3)
    modo_pruebas = forms.BooleanField(label='Modo pruebas', required=False)


    def save(self, *args, **kwargs):
        empresa_nombre = Registry.objects.get( nombre = 'SIC_SMS_NombreEmpresa')
        empresa_nombre.valor = self.cleaned_data['empresa_nombre']
        empresa_nombre.save()

        telefono_default = Registry.objects.get( nombre = 'SIC_SMS_TelDefault')
        telefono_default.valor = self.cleaned_data['telefono_default']
        telefono_default.save()

        enviar_remisiones = 'S' if self.cleaned_data['enviar_remisiones'] else 'N'
        UpdateRegistry('SIC_SMS_EnviarRemisionesPendientes', enviar_remisiones)
        UpdateRegistry('SIC_SMS_DiasPorVencer', self.cleaned_data['dias_atraso'])
        UpdateRegistry('SIC_SMS_InformacionExtra', self.cleaned_data['informacion_extra'])

        resumir_mensajes = 'S' if self.cleaned_data['resumir_mensajes'] else 'N'
        UpdateRegistry('SIC_SMS_ResumirMensajes', resumir_mensajes)
       
        modo_pruebas = 'S' if self.cleaned_data['modo_pruebas'] else 'N'
        UpdateRegistry('SIC_SMS_ModoPruebas', modo_pruebas)

        apikey = Registry.objects.get( nombre = 'SIC_SMS_ApiKey')
        apikey.valor = self.cleaned_data['apikey']
        if apikey.valor:
            apikey.save()

        monto_minimo = Registry.objects.get( nombre = 'SIC_SMS_MontoMinimo')
        monto_minimo.valor = self.cleaned_data['monto_minimo']
        monto_minimo.save()

    def clean_apikey(self,*args,**kwargs):
        apikey= self.cleaned_data['apikey']
        if apikey:
            sms=SMSMasivo(apikey=apikey)
            if sms.credito()['success'] != True:
                raise forms.ValidationError(u'Llave Invalida')

        apikey_registry = Registry.objects.get( nombre = 'SIC_SMS_ApiKey').valor
        if not apikey_registry and not apikey:
            raise forms.ValidationError(u'Campo Obligatorio')

        return apikey





from .models import *
from dal import autocomplete
from django.db.models import Q

autocomplete.register(Cliente,
                name='cliente-autocomplete',
                search_fields=('nombre',),
                choices= Cliente.objects.filter(Q(no_enviar_sms=None) | Q(no_enviar_sms=0)),
                autocomplete_js_attributes={ 'placeholder': 'Busca un cliente... ', },
                widget_js_attributes = {
                                        'max_values': 20,
                                        }
                )


#encoding:utf-8
from django.template import RequestContext
from django.http import HttpResponse,HttpResponseRedirect
from django.contrib.auth.decorators import login_required
# user autentication
from .models import *
from .forms import *
from django.views.generic.list import ListView
from django.shortcuts import render,redirect, get_object_or_404
from cryptography.fernet import Fernet
from django.conf import settings
from django.core.files.storage import default_storage
from django.core.files.base import ContentFile
from datetime import datetime
import os
import json

class ClienteListView(ListView):
    context_object_name = "clientes"
    model = Cliente
    template_name = 'django_msp_sms/clientes/clientes.html'
    paginate_by = 50

    def get_queryset(self):
        
        get_dict = self.request.GET
        form =  ClienteSearchForm(self.request.GET)
        if form.is_valid():
            cliente = form.cleaned_data['cliente']
            nombre = form.cleaned_data['nombre']
            clave = form.cleaned_data['clave']
            clientes = Cliente.objects.all()
            if nombre:
                clientes = clientes.filter(nombre__contains=nombre)
            if clave:
                claves = ClienteClave.objects.filter(clave=clave)
                if claves:
                    clientes = Cliente.objects.filter(pk=claves[0].cliente.id)
            if cliente:
                clientes = Cliente.objects.filter(pk=cliente.id)

        return clientes

    def get_context_data(self, **kwargs):
        context = super(ClienteListView, self).get_context_data(**kwargs)
        context['form'] = ClienteSearchForm(self.request.GET or None)
        return context


@login_required(login_url='/login/')
def IgnorarView(request):
    cliente_id = request.GET['cliente_id']
    cliente = get_object_or_404(Cliente, pk=cliente_id)
    if cliente.no_enviar_sms :
        cliente.no_enviar_sms = False
    else:
        cliente.no_enviar_sms = True
    cliente.save()
    data = { 
            'cliente':cliente.nombre,
        }

    data = json.dumps(data)
    #return render(request, template_name,c)
    return HttpResponse(data, content_type='application/json')

# @login_required(login_url='/login/')
# def ClienteManageView(request, id=None, template_name='django_msp_sms/clientes/cliente.html'):
#     ''' Modificacion de puntos de un cliente '''

#     cliente = get_object_or_404(Cliente, pk=id)
#     form = ClienteManageForm(request.POST or None, instance= cliente)
  
#     #Si los datos de los formularios son correctos # and 
#     if form.is_valid():
#         form.save()
#         return HttpResponseRedirect('/sms/clientes/')
#     c = {'form':form, 'cliente_nombre':cliente.nombre,}  
#     return render_to_response(template_name, c, context_instance=RequestContext(request))

def cargar_archivo(request):
    form=FileForm(request.POST or None)
    directorio=settings.MEDIA_ROOT+'\\llave_saldo\\'
    data=[]
    mensaje=None
    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)

    if form.is_valid():
        now = datetime.now()
        date_time = now.strftime("%m-%d-%Y_%H%M")
        archivo=request.FILES['archivo']
        clave=cargar_clave()
        print("POST")
        print(directorio+archivo.name)
        if os.path.isfile(directorio+archivo.name):
            mensaje="Ya se cargo este archivo de saldo"
            print(mensaje)
        else:
            path = default_storage.save('llave_saldo/'+archivo.name, ContentFile(archivo.read()))
            tmp_file = os.path.join(directorio, path)
            desencript(directorio+archivo.name,clave)
            file = open(directorio+archivo.name, "r")
            for line in file:
                data.append(line.strip())
            if float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())==0:
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=str(float(saldo.valor)+float(data[1]))
                saldo.save()
            else:
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=data[1]
                saldo.save() 
            
            mensaje="Saldo agregado regrese a la pagina principal"
            print(mensaje)

    
    return render( request,'django_msp_sms/clientes/cargar_archivo.html',{'form':form,'mensaje':mensaje,})

def add_archivo(request):
    creditos = request.GET['creditos']
    print("add_creditos",creditos)
    if Registry.objects.get(nombre='SIC_SMS_Saldo').get_value():
        saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
        saldo.valor=str(float(saldo.valor)+float(creditos))
        saldo.save()
    else:
        saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
        saldo.valor=creditos
        saldo.save() 

    archivo={}      
    return HttpResponse(json.dumps(data), content_type='application/json')

def generar_clave():
    clave=Fernet.generate_key()
    with open("sic_clave.key","wb") as archivo_clave:
        archivo_clave.write(clave)

def cargar_clave():
    return open("sic_clave.key","rb").read()

def encript(nom_archivo,clave):
    f=Fernet(clave)
    with open(nom_archivo,"rb") as file:
        archivo_info=file.read()
    encrypted_data=f.encrypt(archivo_info)
    with open(nom_archivo,"wb") as file:
        file.write(encrypted_data)

def desencript(nom_archivo,clave):
    f=Fernet(clave)
    with open(nom_archivo,"rb") as file:
        encrypted_data=file.read()
    decrypted_data=f.decrypt(encrypted_data)
    with open(nom_archivo,"wb") as file:
        file.write(decrypted_data)



# from django.conf.urls import patterns, url, include
from django.urls import path,include
from . import views
from .modulos.preferencias import urls as preferencias_urls
from .modulos.personalizados import urls as personalizados_urls
from .modulos.saldos_clientes import urls as saldos_clientes_urls
from .modulos.clientes import urls as clientes_urls

urlpatterns = (
    path('', views.index),
    #ajax
    path('enviar_sms/', views.enviar_smsView),
    path('enviar_mensaje/', views.enviar_mensaje),
    path('get_creditos/', views.get_creditos),
    path('get_mensajes_personalizados/', views.get_mensajes_personalizados),

    #personalizados
    path('personalizados/por_telefono/', views.personalizadosView),
    path('clientes_autocomplete/', views.ClienteAutocomplete),

    path('', include(preferencias_urls)),
    path('', include(personalizados_urls)),
    path('', include(saldos_clientes_urls)),
    path('', include(clientes_urls)),
)
 


#----encoding:utf-8------------
from django import forms
from .models import *
from dal import autocomplete

class ClienteSearchForm(forms.Form):
    cliente = forms.ModelChoiceField(queryset=Cliente.objects.all(), widget=autocomplete.ModelSelect2(), required=False)
    nombre = forms.CharField(max_length=50,  widget=forms.TextInput(attrs={'class':'form-control', 'placeholder':'nombre...'}), required=False)
    clave = forms.CharField(max_length=20,  widget=forms.TextInput(attrs={'class':'form-control', 'placeholder':'clave...'}),required=False)
    
    def __init__(self, *args, **kwargs):
        super(ClienteSearchForm, self).__init__(*args, **kwargs)
        self.fields['cliente'].widget.attrs['class'] = 'form-control'


class FileForm(forms.Form):
    archivo = forms.FileField(required=False)
    def __init__(self, *args, **kwargs):
        super(FileForm, self).__init__(*args, **kwargs)
        self.fields['archivo'].widget.attrs['class'] = 'form-control'

class ClienteManageForm(forms.ModelForm):

    class Meta:
        model = Cliente
        exclude = ('cuenta_xcobrar','estatus','tipo_cliente', 'condicion_de_pago', 'emir_estado_cuenta', 'cobrar_impuestos', 'moneda', 'nombre', 'generar_interereses',)


#----encoding:utf-8------------
from django import forms
from .models import *
from dal import autocomplete
from django.core.validators import RegexValidator
from django_select2 import forms as s2forms
from dal import autocomplete
from django.forms.widgets import CheckboxSelectMultiple

class ClienteWidget(s2forms.ModelSelect2MultipleWidget):
	search_fields = [
		"nombre__icontains",
	]
class SMSForm(forms.Form):
    telefono =forms.CharField(widget = forms.TextInput(attrs={'class':'form-control', 'placeholder':'Numero de telefono(10 digitos)...'}) )
    mensaje = forms.CharField(max_length=160,  widget = forms.Textarea(attrs={'class':'form-control', 'placeholder':'Escribe tu mensaje aqui (160 caracteres)...','cols':35, 'rows':5, 'maxlength':160, }))

class SelectMultipleClients(forms.Form):
	clientes = forms.ModelMultipleChoiceField(queryset=Cliente.objects.all(), widget=s2forms.Select2Widget())
	#clientes = forms.ModelMultipleChoiceField(widget=s2forms.Select2MultipleWidget(),choices=[(obj.name, obj.name) for obj in Cliente.objects.all()])




procedures = {}

procedures['SIC_SMS_CLIENTE_AT'] = '''
    CREATE OR ALTER PROCEDURE SIC_SMS_CLIENTE_AT
    as
    BEGIN
        if (not exists(
        select 1 from RDB$RELATION_FIELDS rf
        where rf.RDB$RELATION_NAME = 'CLIENTES' and rf.RDB$FIELD_NAME = 'SIC_SMS_NOENVIAR')) then
            execute statement 'ALTER TABLE CLIENTES ADD SIC_SMS_NOENVIAR SMALLINT';
    END  
    '''


#encoding:utf-8
from django.test import TestCase
from .modulos.saldos_clientes.core import formar_mensaje
from django_microsip_base.libs.models_base.models import Registry
modo_pruebas = True


class FormarMensajeTests(TestCase):
    def setUp(self):
        cliente_id = 3636
        cliente = {
            'total': 23900,
            'numero_documentos': 3,
            'email': 'jesusmaherrera@gmail.com',
            'telefono': '6251208151',
            'moneda_nombre': 'Moeda Nacional',
            'moneda_simbolo': 'MN',
            'documentos': [],
        }

        cliente_cargos = {
            'email': cliente['email'],
            'telefono': cliente['telefono'],
            'documentos_numero': cliente['numero_documentos'],
            'documentos': cliente['documentos'],
            'total': '$ {:,.2f}'.format(cliente['total']),
            'cliente_moneda': cliente['moneda_nombre'],
            'cliente_moneda_simbolo': cliente['moneda_simbolo'],
            'cliente_id': cliente_id,
        }

        login = {
            'apikey': Registry.objects.get(nombre='SIC_SMS_ApiKey').valor,
        }

        commun = {
            'empresa_nombre': Registry.objects.get(nombre='SIC_SMS_NombreEmpresa').get_value(),
        }

        self.cliente_cargos_kwargs = {
            'commun': commun,
            'login': login,
            'cargo': cliente_cargos,
        }

    def test_donot_send_in_messaje_morethan_60chars(self):
        """ Para probar que en la variable de mensaje no se envien mas de 60 caracteres."""
        mensaje = formar_mensaje(kwargs=self.cliente_cargos_kwargs)
        mensaje_len = len(mensaje)
        print mensaje_len
        self.assertTrue(mensaje_len < 60)



#encoding:utf-8
import json
import re

from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse
from django.shortcuts import render,redirect
from django.template import RequestContext

# user autentication
from . import core
from . import forms
from .models import *
from microsip_api.apps.sms.core import SMSMasivo
from urllib.request import urlopen
#modo_pruebas = settings.MODO_SERVIDOR == 'PRUEBAS'
from dal import autocomplete
from datetime import datetime
import os

class ClienteAutocomplete(autocomplete.Select2QuerySetView):
    def get_queryset(self):
        # Don't forget to filter out results depending on the visitor !
        if not self.request.user.is_authenticated:
            return Cliente.objects.none()

        qs = Cliente.objects.all()

        if self.q:
            qs = qs.filter(name__istartswith=self.q)

        return qs

@login_required(login_url='/login/')
def index(request, template_name='django_msp_sms/index.html'):
    error = ''
    apikey = None
    creditos = 0
    if Registry.objects.get(nombre='SIC_SMS_InformacionExtra').get_value():
        creditos=Registry.objects.get(nombre='SIC_SMS_InformacionExtra').get_value()
    
    initial_configuration = core.InitialConfiguration()
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    if not initial_configuration.is_valid:
        error = 'Inicializar Configuracion'
    else:
        apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    
    if Registry.objects.get(nombre='SIC_SMS_Saldo').get_value():
        creditos=Registry.objects.get(nombre='SIC_SMS_Saldo').get_value()
    if apikey != 'None':
        pass
    #     sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    #     dic_cred = sms_masivo.credito()
    #     print(urlopen('http://icanhazip.com').read())
    #     #https://www.manusoft.es/raspberry-pi/comprobar-automaticamente-la-direccion-ip-publica/
    #     print(dic_cred['success'])
    #     if dic_cred['success'] == True:
    #         creditos = float(dic_cred['credit'])
    else:
        error = 'Llave no Definida'
    c = {'creditos': creditos, 'error': error, 'modo_pruebas': modo_pruebas}
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def personalizadosView(request, template_name='django_msp_sms/personalizados.html'):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    directorio=settings.MEDIA_ROOT+'\\numeros_invalidos\\'
    now = datetime.now()
    date_time = now.strftime("%m-%d-%Y_%H%M")
    nom_archivo='numeros_invalidos'+date_time+'.txt'

    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)
    file = open(directorio+nom_archivo, "w")
    
    c = {}
    multi = False
    num_enviados = 0
    num_no_enviados = 0
    form = forms.SMSForm(request.POST or None)
    mensaje_respuesta = ''
    estatus = ''
    if form.is_valid():
        mensaje = form.cleaned_data['mensaje']
        mensaje = mensaje.encode('ascii', 'replace')
        telefono = form.cleaned_data['telefono']
        sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
        creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
        if len(telefono.split(',')) > creditos:
            mensaje_respuesta="No tiene sufcientes creditos par enviar los mensajes (Mensajes por enviar "+str(len(telefono.split(',')))+", "+str(creditos)+" credito(s) disponbles) "
        elif (len(telefono.split(',')) > 1):
            for tel in telefono.split(','):
                print(telefono)
                multi = True
                j = sms_masivo.multisend(mensaje=mensaje, telefono=tel)
                if j['code']=='sms_19':
                    mensaje_respuesta="El numero de telefono es fijo o no existe "
                    file.write(tel+'\n')
                    num_no_enviados=num_no_enviados+1
                elif j['code']=='sms_11':
                    creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                    creditos= creditos-1
                    saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                    saldo.valor=str(creditos)
                    saldo.save()
                    mensaje_respuesta = j['message']
                    num_enviados=num_enviados+1
                #mensaje_respuesta = j['message']
                estatus = None
        else:
            j = sms_masivo.send(mensaje=mensaje, telefono=telefono)
            #mensaje_respuesta = j['message']
            estatus = j['code']
            if j['code']=='sms_19':
                mensaje_respuesta="El numero de telefono es fijo o no existe "
                num_no_enviados=num_no_enviados+1
                file.write(telefono+'\n')
            elif j['code']=='sms_11':
                creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                creditos= creditos-1
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=str(creditos)
                saldo.save()
                mensaje_respuesta = j['message']
                num_enviados=num_enviados+1

    

    file.close()
    c = {'mensaje': mensaje_respuesta, 'form': form, 'estatus': estatus, 'multi': multi,'num_no_enviados':num_no_enviados, 'num_enviados':num_enviados,'archivo':'numeros_invalidos\\'+nom_archivo,'nom_archivo':nom_archivo, }
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))



@login_required(login_url='/login/')
def enviar_smsView(request):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    mensaje = request.GET['mensaje']
    mensaje = mensaje.encode('ascii', 'replace')
    telefono = request.GET['telefono']
    numero_mensaje = int(request.GET['numero_mensaje'])
    numero_mensaje += 1
    sms = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    resultado = sms.send(mensaje=mensaje, telefono=telefono)['message']
    data = {
        'telefono': telefono,
        'numero_mensaje': numero_mensaje,
        'resultado': resultado,
    }

    data = json.dumps(data)
    return HttpResponse(data, content_type='application/json')


@login_required(login_url='/login/')
def enviar_mensaje(request):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    telefono = request.GET['telefono']
    mensaje = request.GET['mensaje']
    mensaje = mensaje.encode('ascii', 'replace')

    sms = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    resultado = sms.send(mensaje=mensaje, telefono=telefono)['message']

    data = json.dumps({
        'resultado': resultado,
    })
    return HttpResponse(data, content_type='application/json')


@login_required(login_url='/login/')
def get_creditos(request):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    creditos = float(sms_masivo.credito()['credit'])
    #se envian datos
    if modo_pruebas=='S':
        creditos = len(mensajes)
    data = json.dumps({
        'creditos': creditos,
    })

    return HttpResponse(data, content_type='application/json')


@login_required(login_url='/login/')
def get_mensajes_personalizados(request):
    clientes_ids = str(request.GET['clientes_ids']).replace('[', '').replace(']', '').replace('"', '').split(',')
    mensaje = request.GET['mensaje']
    mensaje = mensaje.encode('ascii', 'replace')

    clientes = ClienteDireccion.objects.filter(cliente__id__in=clientes_ids).order_by('telefono1').values_list('cliente', 'cliente__nombre', 'telefono1',)

    mensajes_clientes = {}
    clientes_con_telefono_invalido = []
    for cliente in clientes:
        cliente_id = cliente[0]
        cliente_nombre = cliente[1].lstrip().rstrip()
        telefono = cliente[2]

        if telefono:
            telefono = unicode(telefono.encode('utf-8'), errors='ignore')
            telefono = re.sub("[^0-9]", "", str(telefono))

            #validacion de telefonos invalidos  y creacion de mensajes
            if len(telefono) != 10 and cliente_nombre not in clientes_con_telefono_invalido:
                clientes_con_telefono_invalido.append(cliente_nombre)
            elif not cliente_id in mensajes_clientes:
                if cliente_nombre in clientes_con_telefono_invalido:
                    clientes_con_telefono_invalido.remove(cliente_nombre)

                mensajes_clientes[cliente_id] = (telefono, mensaje, cliente_nombre)
        else:
            if not cliente_nombre in clientes_con_telefono_invalido:
                clientes_con_telefono_invalido.append(cliente_nombre)

    data = json.dumps({
        'mensajes': mensajes_clientes.values(),
        'clientes_con_telefono_invalido': clientes_con_telefono_invalido,
    })

    return HttpResponse(data, content_type='application/json')



# #encoding:utf-8
# from celery import task
from .modulos.saldos_clientes.core import formar_mensaje


# @task
def enviar_correo(**kwargs):
    data=formar_mensaje(kwargs=kwargs)
    # print("**************************data")
    # print(data)
    return data



# from django.conf.urls import patterns, url
from django.urls import path,include
from .views import ClienteListView,IgnorarView,cargar_archivo,add_archivo

urlpatterns = (
	path('clientes/', ClienteListView.as_view()),
	path('ignorar/', IgnorarView),
	path('cargar_archivo/', cargar_archivo),
	path('add_archivo/', add_archivo),
		
)




from django.db import router
from .models import *
from .config import configuration_registers, extrafields
from microsip_api.comun.comun_functions import exists_table_field


class InitialConfiguration(object):

    def __init__(self):
        self.errors = []
        self.is_valid = True
        self.IsValid()

    def IsValid(self):
        using = router.db_for_write(Cliente)
        self.is_valid = True

        # para validar que todos los registros existan
        for register in configuration_registers:
            if not Registry.objects.filter(nombre=register).exists():
                self.is_valid = False

        for extrafield in extrafields:
            table_name = extrafield[0]
            table_field = extrafield[1]
            if not exists_table_field(table_name, table_field, using):
                self.is_valid = False

        if self.is_valid is True:
            if Registry.objects.get(nombre='SIC_SMS_MontoMinimo').get_value() is None:
                self.is_valid = False

        if not self.is_valid:
            self.errors.append('''Por favor inicializa la configuracion de la aplicacion dando  <a href="/puntos/preferencias/actualizar_tablas/">click aqui</a>''')
            self.is_valid = False



settings = {
    'name': 'Mensajes de Texto',
    'icon_class': 'glyphicon glyphicon-envelope',
    'url': r'/sms/',
    'url_main_path': r'sms/',
    'users': [],
}

configuration_registers = (
    'SIC_SMS_NombreEmpresa',
    'SIC_SMS_TelDefault',
    'SIC_SMS_ApiKey',
    'SIC_SMS_MontoMinimo',
    'SIC_SMS_EnviarRemisionesPendientes',
    'SIC_SMS_ResumirMensajes',
    'SIC_SMS_InformacionExtra',
    'SIC_SMS_DiasPorVencer',
    'SIC_SMS_Saldo',
    'SIC_SMS_Ip_publica',
    'SIC_SMS_ModoPruebas'
    )

extrafields = (
    ('CLIENTES', 'SIC_SMS_NOENVIAR'),
)



#----encoding:utf-8------------
#from dal import autocomplete

from django.conf import settings
from django import forms

from .models import *
from django_select2 import forms as s2forms


class SelectMultipleClients(forms.Form):
    clientes = forms.ModelMultipleChoiceField(queryset=Cliente.objects.all())
    mensaje = forms.CharField(max_length=160,  widget=forms.Textarea(attrs={
        'class': 'form-control', 'placeholder': 'Escribe tu mensaje aqui (160 Caracteres)...', 'cols': 35, 'rows': 5, 'maxlength': 160,
    }))


# Solo si esta instalada la aplicacion de tareas
if 'djmicrosip_tareas' in settings.EXTRA_MODULES:
    from djmicrosip_tareas.models import ProgrammedTask

    class ProgrammedTaskForm(forms.ModelForm):
        period_start_datetime = forms.CharField(label='Inicio', widget=forms.TextInput(attrs={'class': 'form-control', 'placeholder': 'Fecha inicio periodo...'}))
        period_end_datetime = forms.CharField(label='Fin', widget=forms.TextInput(attrs={'class': 'form-control', 'placeholder': '...'}), required=False)
        period_quantity = forms.CharField(widget=forms.TextInput(attrs={'class': 'form-control', 'placeholder': 'unidades...'}))
        next_execution = forms.CharField(widget=forms.HiddenInput(), required=False)

        class Meta:
            model = ProgrammedTask
            exclude = ('description', 'command_type', 'command', 'status', 'last_execution',)
            widgets = {
                'period_unit': forms.Select(attrs={'class': 'form-control'}),
            }



# from django.conf.urls import patterns, url
from django.urls import path,include
from .views import PreferenciasManageView,InitialzeConfigurationDatabase

urlpatterns = (
path('preferencias/', PreferenciasManageView),
path('inicializar/', InitialzeConfigurationDatabase),
		
)




# #encoding:utf-8
from microsip_api.apps.sms.core import SMSMasivo
from django.conf import settings
modo_pruebas = settings.MODO_SERVIDOR == 'PRUEBAS'
from .models import *
from datetime import datetime

def formar_mensaje(kwargs):
    cargo = kwargs['kwargs']['cargo']
    commun = kwargs['kwargs']['commun']
    login = kwargs['kwargs']['login']
    options = kwargs['kwargs']['options']
    cargo['total'] = cargo['total'].replace('$ ', '')[0:-3]
    detalles_str = ''
    for documento in cargo['documentos']:
        documento['saldo_cargo'] = documento['saldo_cargo'][0:-3]
        detalles_str += '%s- %s, ' % (documento['folio'], documento['saldo_cargo'])
    detalles_str = detalles_str[0:-1]
    mensaje = '%s: Edo de Cta: %sTotal= %s en %s Documentos.' % (commun['empresa_nombre'], detalles_str, cargo['total'], cargo['documentos_numero'])
    # Si solo fue un documento
    if cargo['documentos_numero'] == 1:
        mensaje = '%s: Edo de Cta: Total= %s en %s' % (commun['empresa_nombre'], cargo['total'], cargo['documentos'][0]['folio'])

    if len(mensaje) > 160:
        mensaje = '%s: Edo de Cta: Total= %s en %s Documentos.' % (commun['empresa_nombre'], cargo['total'], cargo['documentos_numero'])

    mensaje += ' Docs en %s' % cargo['cliente_moneda_simbolo']
    if commun['informacion_extra']:
        if (len(mensaje)+len(commun['informacion_extra'])<=160):
            mensaje += ' %s' % commun['informacion_extra']
    
    #mensaje = mensaje[0:160]
    sms_masivo = SMSMasivo(apikey=login['apikey'], pruebas=modo_pruebas)
    data=sms_masivo.send(mensaje=mensaje, telefono=cargo['telefono'])

    # print("///////////////sms_masivo")
    # print(data)
    return data


def formar_mensaje_por_vencer(kwargs):
    dias_por_vencer = int(Registry.objects.get(nombre='SIC_SMS_DiasPorVencer').get_value())
    cargos = kwargs['data']['cargos']
    commun = kwargs['commun']
    login = kwargs['login']
    options = kwargs['options']
    for cargo in cargos:
        detalles = False
        cargo['total'] = cargo['total'].replace('$ ', '')[0:-3]
        detalles_str = 'Hoy faltan %s dias para vencer: ' % dias_por_vencer
        for documento in cargo['documentos']:
            documento['saldo_cargo'] = documento['saldo_cargo'][0:-3]
            vencimiento_date = datetime.strptime(documento['vencimiento'], "%d/%m/%Y").date()
            dias_dif = (vencimiento_date - datetime.now().date()).days
            if dias_dif == dias_por_vencer:
                detalles_str += 'Folio : %s = %s;' % (documento['folio'], documento['saldo_cargo'])
                detalles = True
        detalles_str = detalles_str[0:-1]
        mensaje = '%s: Le informa: %s' % (commun['empresa_nombre'], detalles_str)

        mensaje += ' Docs en %s.' % cargo['cliente_moneda_simbolo']
        if commun['informacion_extra']:
            mensaje += ' %s' % commun['informacion_extra']
        sms_masivo = SMSMasivo(apikey=login['apikey'], pruebas=modo_pruebas)
        if detalles:
            print( sms_masivo.send(mensaje=mensaje, telefono=cargo['telefono']))
        return mensaje


#----encoding:utf-8------------
from django import forms
from .models import *
from django.core.validators import RegexValidator
from dal import autocomplete

class SMSForm(forms.Form):
    telefono =forms.CharField(required=False,widget = forms.TextInput(attrs={'class':'form-control', 'placeholder':'Numero de telefono(10 digitos)...'}) )
    mensaje = forms.CharField(widget = forms.Textarea(attrs={'class':'form-control', 'placeholder':'Escribe tu mensaje aqui (160 Caracteres)...','cols':35, 'rows':5, 'maxlength':160, }))

class SelectMultipleClients(forms.Form):
	clientes = forms.ModelMultipleChoiceField(queryset=Cliente.objects.all())
	mensaje = forms.CharField(max_length=160,  widget = forms.Textarea(attrs={'class':'form-control', 'placeholder':'Escribe tu mensaje aqui (160 Caracteres)...','cols':35, 'rows':5, 'maxlength':160, }))
	

class ZonaForm(forms.Form):
	zona = forms.ModelChoiceField(queryset=Zona.objects.all(), widget= forms.Select(attrs={'class':'form-control'}))
	mensaje = forms.CharField(max_length=160,  widget = forms.Textarea(attrs={'class':'form-control', 'placeholder':'Escribe tu mensaje aqui (160 Caracteres)...','cols':35, 'rows':5, 'maxlength':160, }))




#encoding:utf-8
from microsip_api.comun.sic_db import get_conecctionname,first_or_none
from django.shortcuts import render,redirect
from django.template import RequestContext
from django.contrib.auth.decorators import login_required
# user autentication
from .models import *
from .forms import *
from django.http import HttpResponse,HttpResponseRedirect
from .procedures import procedures as procedures_sic
from django.db import connections, router
from django.core import management
from ...config import configuration_registers, extrafields


@login_required(login_url='/login/')
def PreferenciasManageView(request, template_name='django_msp_sms/preferencias.html'):
    msg = ''
    form_initial = {
        'empresa_nombre': Registry.objects.get(nombre='SIC_SMS_NombreEmpresa').get_value(),
        'informacion_extra': Registry.objects.get(nombre='SIC_SMS_InformacionExtra').get_value(),
        'telefono_default': Registry.objects.get(nombre='SIC_SMS_TelDefault').get_value(),
        'apikey': Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value(),
        'enviar_remisiones': Registry.objects.get(nombre='SIC_SMS_EnviarRemisionesPendientes').get_value() == 'S',
        'resumir_mensajes': Registry.objects.get(nombre='SIC_SMS_ResumirMensajes').get_value() == 'S',
        'monto_minimo': Registry.objects.get(nombre='SIC_SMS_MontoMinimo').get_value(),
        'dias_atraso': Registry.objects.get(nombre='SIC_SMS_DiasPorVencer').get_value(),
        'saldo': Registry.objects.get(nombre='SIC_SMS_Saldo').get_value(),
        'ip_publica': Registry.objects.get(nombre='SIC_SMS_Ip_publica').get_value(),
        'modo_pruebas': Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S',
    }
    form = PreferenciasManageForm(request.POST or None, initial=form_initial)
    if form.is_valid():
        form.save()
        msg = 'Datos guardados correctamente'
    c = {'form': form, 'msg': msg, }
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def InitialzeConfigurationDatabase(request):
    """ Agrega campos nuevos en tablas de base de datos. """
    padre = first_or_none(Registry.objects.filter(nombre='PreferenciasEmpresa'))
    if request.user.is_superuser and padre:
        
        using = router.db_for_write(Registry)
        for procedure  in procedures_sic:
            c = connections[using].cursor()
            c.execute(procedures_sic[procedure])
            c.execute('EXECUTE PROCEDURE %s;'%procedure)
            c.execute('DROP PROCEDURE %s;'%procedure)
            c.close()
            
        management.call_command( 'syncdb', database = using, interactive= False)       

        for register in configuration_registers:
            if not Registry.objects.filter(nombre = register).exists():
                Registry.objects.create(
                    nombre = register,
                    tipo = 'V',
                    padre = padre,
                    valor= '',
                )
                
    return HttpResponseRedirect('/sms/preferencias')



#encoding:utf-8
from . import forms
from ...tasks import enviar_correo
from .core import formar_mensaje_por_vencer
from .models import *
from datetime import datetime, timedelta
from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseRedirect
from django.shortcuts import render,redirect
from django.template import RequestContext
from microsip_api.apps.cuentasxcobrar.core import CargosClientes
from microsip_api.apps.sms.core import SMSMasivo
from microsip_api.comun.sic_db import first_or_none
import json
from datetime import datetime
import os
#modo_pruebas = settings.MODO_SERVIDOR == 'PRUEBAS'


@login_required(login_url='/login/')
def PorSeleccionView(request, template_name='django_msp_sms/saldos_clientes/por_seleccion.html'):
    form = forms.SelectMultipleClients(request.POST or None)
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    print(modo_pruebas)
    c = {'form': form}
    
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def get_mensajes_saldos(request):
    ids = json.loads(request.GET['data'])
    enviar_remisiones = Registry.objects.get(nombre='SIC_SMS_EnviarRemisionesPendientes').get_value() == 'S'
    monto_minimo_mn = Registry.objects.get(nombre='SIC_SMS_MontoMinimo').get_value() or 0
    cargos = CargosClientes('sms', tomar_remisiones=enviar_remisiones, clientes_ids=ids, monto_minimo_mn=monto_minimo_mn)
    # print("+++++++++++++++++++++++++++++++++++++++++++")
    # print(cargos)
    clientes_telefono_invalido = cargos.clientes_informacion_invalida
    clientes_sin_mensaje = cargos.clientes_sin_mensaje
    #clientes_sin_mensaje = map(str, clientes_sin_mensaje)
    # Validacion de saldo
    # se checa disponiblidad de credito
    error = None
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    #print()
    sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    creditos =  float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
    if modo_pruebas:
        creditos = len(cargos)
    if creditos < len(cargos):
        error = 'Creditos Insuficientes.<br>Creditos Disponibles: %s<br>Mensajes por enviar: %s<br>Creditos Necesarios: %s' % (creditos, len(cargos), len(cargos)-creditos)
        print(error)
    # print("**********")
    # print(ids)
    # print(cargos)
    # print(clientes_telefono_invalido)
    # print(clientes_sin_mensaje)
    # print(error)
    data = json.dumps({
        'cargos': cargos,
        'clientes_telefono_invalido': clientes_telefono_invalido,
        'clientes_sin_mensaje': clientes_sin_mensaje,
        'error': error,
    })

    return HttpResponse(data, content_type='application/json')


@login_required(login_url='/login/')
def enviar_cargos_seleccion(request):
    cargo = json.loads(request.GET['data'])
    creditos=0
    # print("////////////////////////////////////////")
    # print(cargo)
    directorio=settings.MEDIA_ROOT+'\\numeros_invalidos\\'
    now = datetime.now()
    date_time = now.strftime("%m-%d-%Y_%H%M")
    nom_archivo='numeros_invalidos'+date_time+'.txt'

    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)
    

    login = {
        'apikey': Registry.objects.get(nombre='SIC_SMS_ApiKey').valor,
    }

    commun = {
        'empresa_nombre': Registry.objects.get(nombre='SIC_SMS_NombreEmpresa').get_value(),
        'informacion_extra': Registry.objects.get(nombre='SIC_SMS_InformacionExtra').get_value(),
    }
    resumir_mensajes = Registry.objects.get(nombre='SIC_SMS_ResumirMensajes').get_value() == 'S'
    kwargs = {
        'commun': commun,
        'login': login,
        'cargo': cargo,
        'options': {
            'resumir': resumir_mensajes,
        }
    }
    datos=enviar_correo(kwargs=kwargs)
    print("***************************RESULTADO***************************")
    print(datos)
    if datos['code'] == 'sms_11':
       creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
       creditos= creditos-1
       saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
       saldo.valor=str(creditos)
       saldo.save()
    else:
        print(str(datos['references'][0]['number']))
        file = open(directorio+nom_archivo, "w")
        file.write(str(datos['references'][0]['number']).replace('52','')+'\n')
        file.close()
    #print(creditos)

    resultado = 'Mensaje enviado'

    data = json.dumps({
        'resultado': datos,
        'media_url':settings.MEDIA_URL,
        'nom_archivo':nom_archivo,
        'carpeta':'/numeros_invalidos/',
    })
    return HttpResponse(data, content_type='application/json')


@login_required(login_url='/login/')
def todos_view(request, template_name='django_msp_sms/saldos_clientes/todos.html'):
    return render(request, template_name,{})
    #return render_to_response(template_name, {}, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def enviar_cargos_por_vencer(request,  template_name='django_msp_sms/saldos_clientes/por_vencer.html'):
    ids = []
    enviar_remisiones = Registry.objects.get(nombre='SIC_SMS_EnviarRemisionesPendientes').get_value() == 'S'
    monto_minimo_mn = Registry.objects.get(nombre='SIC_SMS_MontoMinimo').get_value() or 0
    cargos = CargosClientes('sms', tomar_remisiones=enviar_remisiones, clientes_ids=ids, monto_minimo_mn=monto_minimo_mn)
    clientes_telefono_invalido = cargos.clientes_informacion_invalida
    clientes_sin_mensaje = cargos.clientes_sin_mensaje
    clientes_sin_mensaje = map(str, clientes_sin_mensaje)
    error = ''
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value() == 'S'
    sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
    creditos = float(sms_masivo.credito()['credit'])
    if modo_pruebas:
        creditos = len(cargos)
    if creditos < len(cargos):
        error = 'Creditos Insuficientes.<br>Creditos Disponibles: %s<br>Mensajes por enviar: %s<br>Creditos Necesarios: %s' % (creditos, len(cargos), len(cargos)-creditos)

    data = {
        'cargos': cargos,
        'clientes_telefono_invalido': clientes_telefono_invalido,
        'clientes_sin_mensaje': clientes_sin_mensaje,
        'error': error,
    }

    login = {
        'apikey': Registry.objects.get(nombre='SIC_SMS_ApiKey').valor,
    }

    commun = {
        'empresa_nombre': Registry.objects.get(nombre='SIC_SMS_NombreEmpresa').get_value(),
        'informacion_extra': Registry.objects.get(nombre='SIC_SMS_InformacionExtra').get_value(),
    }

    resumir_mensajes = Registry.objects.get(nombre='SIC_SMS_ResumirMensajes').get_value() == 'S'
    kwargs = {
        'commun': commun,
        'login': login,
        'data': data,
        'options': {
            'resumir': resumir_mensajes,
        }
    }

    formar_mensaje_por_vencer(kwargs=kwargs)
    resultado = 'Mensaje enviado'

    data = {
        'resultado': resultado,
    }
    return render(request, template_name,c)
    #return render_to_response(template_name, data, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def saldos_automaticos_preferencias(request, template_name='django_msp_sms/saldos_clientes/saldos_automaticos_preferencias.html'):
    """
    Guarda o actualiza una la tarea para envio de mensajes Automaticos

    **** Si next_execution(Siguiente ejecucion) no se a indicado nunca
         la fecha de siguiente ejecucion sera la fecha de inicio. ****
    """

    context = {
        'errors': []
    }

    if 'djmicrosip_tareas' in settings.EXTRA_MODULES:
        from djmicrosip_tareas.models import ProgrammedTask
        task = first_or_none(ProgrammedTask.objects.filter(description='SMS Saldos Automaticos')) or ProgrammedTask()

        form = forms.ProgrammedTaskForm(request.POST or None, instance=task)
        if form.is_valid():
            task = form.save(commit=False)
            # Si no se acreado le agregamos los paramentros comunes de la tarea
            if not task.id:
                task.description = 'SMS Saldos Automaticos'
                task.command_type = 'http'
                task.command = 'http://127.0.0.1:8001/sms/saldos/todos_automatico/'
            task.save()
            form = forms.ProgrammedTaskForm(None, instance=task)
            context['msg'] = 'Información actualizada correctamente.'
        context['form'] = form
    else:
        context['errors'].append('Por favor instalarla para poder configurar esta opción')

    return render(request, template_name,c)
    #return render_to_response(template_name, context, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def envia_saldos_automaticos(request):
    enviar_remisiones = Registry.objects.get(nombre='SIC_SMS_EnviarRemisionesPendientes').get_value() == 'S'
    monto_minimo_mn = Registry.objects.get(nombre='SIC_SMS_MontoMinimo').get_value() or 0
    cargos = CargosClientes('sms', tomar_remisiones=enviar_remisiones, clientes_ids=[], monto_minimo_mn=monto_minimo_mn)

    login = {
        'apikey': Registry.objects.get(nombre='SIC_SMS_ApiKey').valor,
    }

    commun = {
        'empresa_nombre': Registry.objects.get(nombre='SIC_SMS_NombreEmpresa').get_value(),
    }

    kwargs = {
        'commun': commun,
        'login': login,
    }

    for cargo in cargos:
        kwargs['cargo'] = cargo
        enviar_correo(kwargs=kwargs)

    return HttpResponseRedirect('/sms/')


@login_required(login_url='/login/')
def saldos_por_vencer_automaticos_preferencias(request, template_name='django_msp_sms/saldos_clientes/saldos_automaticos_por_vencer_preferencias.html'):
    context = {
        'errors': []
    }
    if 'djmicrosip_tareas' in settings.EXTRA_MODULES:
        from djmicrosip_tareas.models import ProgrammedTask
        task = first_or_none(ProgrammedTask.objects.filter(description='SMS Saldos por vencer Automaticos')) or ProgrammedTask()

        form = forms.ProgrammedTaskForm(request.POST or None, instance=task)
        if form.is_valid():
            task = form.save(commit=False)
            if not task.id:
                task.description = 'SMS Saldos por vencer Automaticos'
                task.command_type = 'http'
                task.command = 'http://127.0.0.1:8001/sms/saldos/enviar_por_vencer/'
            task.save()
            form = forms.ProgrammedTaskForm(None, instance=task)
        context['form'] = form
    else:
        context['errors'].append('Por favor instalarla para poder configurar esta opción')

    return render(request, template_name,c)
    #return render_to_response(template_name, context, context_instance=RequestContext(request))


# from django.conf.urls import patterns, url
from django.urls import path,include
from .views import TodosView, PorSeleccionView, ZonaView

urlpatterns = (
	path('personalizados/todos/', TodosView),
	path('personalizados/por_seleccion/', PorSeleccionView),	
	path('personalizados/por_zona/', ZonaView),
)




#encoding:utf-8
from django.shortcuts import render,redirect
from django.template import RequestContext
from django.contrib.auth.decorators import login_required
# user autentication
from .models import *
from .forms import *
from .core import *
from microsip_api.apps.sms.core import SMSMasivo
from django.conf import settings
from datetime import datetime
import os

#modo_pruebas = settings.MODO_SERVIDOR == 'PRUEBAS'


def get_num_enviados(respuestas):
    num_enviados = 0
    if type(respuestas) == list:
        num_enviados = 0
        for m in respuestas:
            if m['estatus'] == 'ok':
                num_enviados+=1        
    return num_enviados

@login_required(login_url='/login/')
def PorSeleccionView(request, template_name='django_msp_sms/personalizados/por_seleccion.html'):

    apikey=str(Registry.objects.get( nombre = 'SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value()

    directorio=settings.MEDIA_ROOT+'\\numeros_invalidos\\'
    now = datetime.now()
    date_time = now.strftime("%m-%d-%Y_%H%M")
    nom_archivo='numeros_invalidos'+date_time+'.txt'

    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)
    file = open(directorio+nom_archivo, "w")

    clientes_con_telefono_invalido=[]
    mensaje_respuesta = ''
    estatus = ''
    multi=False
    num_enviados = 0
    num_no_enviados = 0
    form = SelectMultipleClients(
        request.POST or None)
    if form.is_valid():
        mensaje = form.cleaned_data['mensaje']
        clientes = form.cleaned_data['clientes']
        print("clientes")
        print(clientes)
        telfonos_clientes= TelefonosClientes(clientes=clientes)
        telefonos = telfonos_clientes.telefonos
        print(telefonos)
        clientes_con_telefono_invalido = telfonos_clientes.clientes_con_telefono_invalido
        
        if None in clientes_con_telefono_invalido:
            clientes_con_telefono_invalido.remove(None)

        sms_masivo=SMSMasivo(apikey=apikey,pruebas=modo_pruebas)
        creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
        if len(telefonos) > creditos:
            mensaje_respuesta="No tiene sufcientes creditos par enviar los mensajes (Mensajes por enviar "+str(len(telefonos))+", "+str(creditos)+" credito(s) disponbles) "
        elif (len(telefonos)>1):            
            #telefono=",".join(telefonos)
            multi=True

            for telefono in telefonos:
                print(telefono)
                j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
                if j['code']=='sms_19':
                    num_no_enviados=num_no_enviados+1
                    mensaje_respuesta="Numero de telefono es fijo o no existe"
                    file.write(telefono+'\n')
                    print("no")
                elif j['code']=='sms_11':
                    num_enviados=num_enviados+1
                    print("si")
                    creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                    creditos= creditos-1
                    saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                    saldo.valor=str(creditos)
                    saldo.save()
                    mensaje_respuesta = j['message']
                    #mensaje_respuesta = j['message']
                    estatus = j['code']
                    #mensaje_respuesta = j['message']
        elif len(telefonos)!= 0:
            telefono=telefonos[0]
            j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
            if j['code']=='sms_19':
                num_no_enviados=num_no_enviados+1
                mensaje_respuesta="Numero de telefono es fijo o no existe"
                file.write(telefono+'\n')
            elif j['code']=='sms_11':
                num_enviados=num_enviados+1
                creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                creditos= creditos-1
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=str(creditos)
                saldo.save()
                mensaje_respuesta = j['message']
                #mensaje_respuesta = j['message']
                estatus = j['code']
        else:
            mensaje_respuesta='Ningun Telefono es Valido'

    file.close()
        #num_enviados=get_num_enviados(mensaje_respuesta)
        
    c={'mensaje':mensaje_respuesta, 'form':form,'estatus':estatus,'multi':multi,'clientes_con_telefono_invalido':clientes_con_telefono_invalido, 'num_enviados':num_enviados, 'num_no_enviados':num_no_enviados,'archivo':'numeros_invalidos\\'+nom_archivo,'nom_archivo':nom_archivo,}

    return render(request, template_name,c)
    #return render_to_response( template_name, c , context_instance = RequestContext( request ) )

@login_required(login_url='/login/')
def TodosView( request, template_name = 'django_msp_sms/personalizados/todos.html' ):
    apikey=str(Registry.objects.get( nombre = 'SIC_SMS_ApiKey').get_value())
    num_enviados=0
    num_no_enviados = 0
    clientes_con_telefono_invalido=[]
    c={}
    multi=False
    form = SMSForm(request.POST or None)
    mensaje_respuesta = ''
    estatus = ''
    
    directorio=settings.MEDIA_ROOT+'\\numeros_invalidos\\'
    now = datetime.now()
    date_time = now.strftime("%m-%d-%Y_%H%M")
    nom_archivo='numeros_invalidos'+date_time+'.txt'

    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)
    file = open(directorio+nom_archivo, "w")
    
    if form.is_valid():
        mensaje = form.cleaned_data['mensaje']
        telfonos_clientes=TelefonosClientes()
        telefonos = telfonos_clientes.telefonos
        clientes_con_telefono_invalido = telfonos_clientes.clientes_con_telefono_invalido
        if None in clientes_con_telefono_invalido:
            clientes_con_telefono_invalido.remove(None)
        sms_masivo=SMSMasivo(apikey=apikey,pruebas=None)
        #creditos_antes =int(sms_masivo.credito()['credito'])

        creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
        if len(telefonos) > creditos:
            mensaje_respuesta="No tiene sufcientes creditos par enviar los mensajes (Mensajes por enviar "+str(len(telefonos))+", "+str(creditos)+" credito(s) disponbles) "
        elif (len(telefonos)>1):            
            #telefono=",".join(telefonos)
            multi=True

            for telefono in telefonos:
                print(telefono)
                j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
                if j['code']=='sms_19':
                    num_no_enviados=num_no_enviados+1
                    mensaje_respuesta="Numero de telefono es fijo o no existe"
                    file.write(telefono+'\n')
                    print("no")
                elif j['code']=='sms_11':
                    num_enviados=num_enviados+1
                    print("si")
                    creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                    creditos= creditos-1
                    saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                    saldo.valor=str(creditos)
                    saldo.save()
                    mensaje_respuesta = j['message']
                    #mensaje_respuesta = j['message']
                    estatus = j['code']
                    #mensaje_respuesta = j['message']
        elif len(telefonos)!= 0:
            telefono=telefonos[0]
            j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
            if j['code']=='sms_19':
                num_no_enviados=num_no_enviados+1
                mensaje_respuesta="Numero de telefono es fijo o no existe"
                file.write(telefono+'\n')
            elif j['code']=='sms_11':
                num_enviados=num_enviados+1
                creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                creditos= creditos-1
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=str(creditos)
                saldo.save()
                mensaje_respuesta = j['message']
                #mensaje_respuesta = j['message']
                estatus = j['code']
        else:
            mensaje_respuesta='Ningun Telefono es Valido'
        # num_enviados=get_num_enviados(mensaje_respuesta) 
    file.close()
    c={'mensaje':mensaje_respuesta,'form':form,'estatus':estatus,'multi':multi,'clientes_con_telefono_invalido':clientes_con_telefono_invalido,'num_enviados':num_enviados,'num_no_enviados':num_no_enviados,'archivo':'numeros_invalidos\\'+nom_archivo,'nom_archivo':nom_archivo, }

    return render(request, template_name,c)
    #return render_to_response( template_name, c, context_instance = RequestContext( request ) )


@login_required(login_url='/login/')
def ZonaView(request, template_name='django_msp_sms/personalizados/zona.html'):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    modo_pruebas=Registry.objects.get(nombre='SIC_SMS_ModoPruebas').get_value()
    print(modo_pruebas)
    sms_masivo = None
    num_enviados = 0
    num_no_enviados = 0
    creditos_antes = 0
    creditos_despues = 0
    clientes_con_telefono_invalido = []
    c = {}
    multi = False
    form = ZonaForm(request.POST or None)
    mensaje_respuesta = ''
    estatus = ''
    
    directorio=settings.MEDIA_ROOT+'\\numeros_invalidos\\'
    now = datetime.now()
    date_time = now.strftime("%m-%d-%Y_%H%M")
    nom_archivo='numeros_invalidos'+date_time+'.txt'

    try:
        os.mkdir(directorio)
    except OSError:
        print("La creación del directorio %s falló" % directorio)
    else:
        print("Se ha creado el directorio: %s " % directorio)
    file = open(directorio+nom_archivo, "w")

    if form.is_valid():

        mensaje = form.cleaned_data['mensaje']
        zona = form.cleaned_data['zona']

        telfonos_clientes = TelefonosClientes(zona=zona)
        telefonos = telfonos_clientes.telefonos
        clientes_con_telefono_invalido = telfonos_clientes.clientes_con_telefono_invalido
        print(telfonos_clientes.telefonos)
        if None in clientes_con_telefono_invalido:
            clientes_con_telefono_invalido.remove(None)

        sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)
        print("telefonos")
        print(telefonos)
        
        creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
        if len(telefonos) > creditos:
            mensaje_respuesta="No tiene sufcientes creditos par enviar los mensajes (Mensajes por enviar "+str(len(telefonos))+", "+str(creditos)+" credito(s) disponbles) "
        elif (len(telefonos)>1):            
            #telefono=",".join(telefonos)
            multi=True

            for telefono in telefonos:
                print(telefono)
                j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
                if j['code']=='sms_19':
                    num_no_enviados=num_no_enviados+1
                    mensaje_respuesta="Numero de telefono es fijo o no existe"
                    file.write(telefono+'\n')
                    print("no")
                elif j['code']=='sms_11':
                    num_enviados=num_enviados+1
                    print("si")
                    creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                    creditos= creditos-1
                    saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                    saldo.valor=str(creditos)
                    saldo.save()
                    mensaje_respuesta = j['message']
                    #mensaje_respuesta = j['message']
                    estatus = j['code']
                    #mensaje_respuesta = j['message']
        elif len(telefonos)!= 0:
            telefono=telefonos[0]
            j = sms_masivo.send(mensaje=mensaje,telefono=telefono)
            if j['code']=='sms_19':
                num_no_enviados=num_no_enviados+1
                mensaje_respuesta="Numero de telefono es fijo o no existe"
                file.write(telefono+'\n')
            elif j['code']=='sms_11':
                num_enviados=num_enviados+1
                creditos= float(Registry.objects.get(nombre='SIC_SMS_Saldo').get_value())
                creditos= creditos-1
                saldo = Registry.objects.get(nombre = 'SIC_SMS_Saldo')
                saldo.valor=str(creditos)
                saldo.save()
                mensaje_respuesta = j['message']
                #mensaje_respuesta = j['message']
                estatus = j['code']
        else:
            mensaje_respuesta='Ningun Telefono es Valido'
        #num_enviados = get_num_enviados(mensaje_respuesta)
    file.close()
    c = {'mensaje': mensaje_respuesta, 'form': form, 'estatus': estatus, 'multi': multi, 'clientes_con_telefono_invalido': clientes_con_telefono_invalido, 'num_enviados': num_enviados,'num_no_enviados':num_no_enviados,'archivo':'numeros_invalidos\\'+nom_archivo,'nom_archivo':nom_archivo,}
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))


@login_required(login_url='/login/')
def archivoView(request, template_name='django_msp_sms/personalizados.html'):
    apikey = str(Registry.objects.get(nombre='SIC_SMS_ApiKey').get_value())
    c = {}
    multi = False
    form = SMSForm(request.POST or None)
    mensaje_respuesta = ''
    estatus = ''
    if form.is_valid():
        mensaje = form.cleaned_data['mensaje']
        mensaje = mensaje.encode('ascii', 'replace')
        telefono = form.cleaned_data['telefono']
        sms_masivo = SMSMasivo(apikey=apikey, pruebas=modo_pruebas)

        if (len(telefono.split(',')) > 1):
            multi = True
            j = sms_masivo.multisend(mensaje=mensaje, telefono=telefono)
            mensaje_respuesta = j['respuestas']
            estatus = None
        else:
            j = sms_masivo.send(mensaje=mensaje, telefono=telefono)
            mensaje_respuesta = j['mensaje']
            estatus = j['estatus']

    c = {'mensaje': mensaje_respuesta, 'form': form, 'estatus': estatus, 'multi': multi, }
    return render(request, template_name,c)
    #return render_to_response(template_name, c, context_instance=RequestContext(request))



import os, time, compileall, sys
from setuptools import setup, find_packages
import pathlib

if "sdist" in sys.argv:
    path = os.path.abspath(os.path.dirname(__file__))+"\\django_msp_sms\\"
    compileall.compile_dir(path, force=True)

# README = open(os.path.join(os.path.dirname(__file__), 'README.txt')).read()
with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()
REQUIREMENTS = [i.strip() for i in open("requirements.txt").readlines()]

here = pathlib.Path(__file__).parent.resolve()
long_description = (here / 'README.rst').read_text(encoding='utf-8')
 # allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django_msp_sms',
    version='3.0.2',
    packages=find_packages(),
    include_package_data=True,
    license='BSD License',
    description='django_msp_sms',
    long_description="Mensajes de Texto",
    url='',
    author='Servicios de Ingenieria Computacional',
    author_email='jesusmahererra@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=REQUIREMENTS,
)



# from django.conf.urls import patterns
from django.urls import path,include
from . import views

urlpatterns = (
    path('saldos/por_seleccion/', views.PorSeleccionView),
    path('saldos/get_mensajes_saldos/', views.get_mensajes_saldos),
    path('saldos/enviar_cargo/', views.enviar_cargos_seleccion),
    path('saldos/todos/', views.todos_view),
    path('saldos/todos_automatico_preferencias/', views.saldos_automaticos_preferencias),
    path('saldos/todos_automatico/', views.envia_saldos_automaticos),
    path('saldos/enviar_por_vencer/', views.enviar_cargos_por_vencer),
    path('saldos/por_vencer_automatico_preferencias/', views.saldos_por_vencer_automaticos_preferencias),
)
